function nman = mutacao(man,p)
% FUNÇÃO MUTAÇÃO - Gera uma mutação em um indivíduo
%
% 		nman = mutacao(man,p)
%
% onde:
%		 man: individuo que sofrera a mutacao
%		 p: probabilidade de ocorrer mutação (default: 0.05)
%		 nman: novo individuo que sofreu a mutacao
%
% Marcelo Farenzena
% 11 / 2004

if nargin < 1
   break
end

if nargin == 1
   p = 0.05;
end

if rand(1) < p
   nb = length(man); 			% número de gens do papai
   gm = ceil(rand(1)*nb);		% gene modificado
   nman = man;
   if man(gm) == '1'
      nman(gm) = '0';
   else
      nman(gm) = '1';
   end   
else
   nman = man;
end






